""" Cisco_IOS_XR_ncs6k_acl_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ncs6k\-acl package operational data.

This module contains definitions
for the following management objects\:
  access\-list\-hardware\: Root class of accesslist hardware

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class SseGrant(Enum):
    """
    SseGrant

    ACL grant

    .. data:: permit = 1

    	Grant permit

    .. data:: deny = 2

    	Grant deny

    """

    permit = Enum.YLeaf(1, "permit")

    deny = Enum.YLeaf(2, "deny")


class SsePfilterAddr(Enum):
    """
    SsePfilterAddr

    Address types

    .. data:: ipv4 = 0

    	IPv4

    .. data:: ipv6 = 1

    	IPv6

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")



class AccessListHardware(Entity):
    """
    Root class of accesslist hardware
    
    .. attribute:: nodes
    
    	Accesslist nodes
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes>`
    
    

    """

    _prefix = 'ncs6k-acl-oper'
    _revision = '2017-05-01'

    def __init__(self):
        super(AccessListHardware, self).__init__()
        self._top_entity = None

        self.yang_name = "access-list-hardware"
        self.yang_parent_name = "Cisco-IOS-XR-ncs6k-acl-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"nodes" : ("nodes", AccessListHardware.Nodes)}
        self._child_list_classes = {}

        self.nodes = AccessListHardware.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._children_yang_names.add("nodes")
        self._segment_path = lambda: "Cisco-IOS-XR-ncs6k-acl-oper:access-list-hardware"


    class Nodes(Entity):
        """
        Accesslist nodes
        
        .. attribute:: node
        
        	Accesslist node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node>`
        
        

        """

        _prefix = 'ncs6k-acl-oper'
        _revision = '2017-05-01'

        def __init__(self):
            super(AccessListHardware.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "access-list-hardware"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"node" : ("node", AccessListHardware.Nodes.Node)}

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ncs6k-acl-oper:access-list-hardware/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(AccessListHardware.Nodes, [], name, value)


        class Node(Entity):
            """
            Accesslist node
            
            .. attribute:: node_name  <key>
            
            	Node name
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: egress
            
            	Accesslist direction egress
            	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress>`
            
            .. attribute:: ingress
            
            	Accesslist direction ingress
            	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress>`
            
            

            """

            _prefix = 'ncs6k-acl-oper'
            _revision = '2017-05-01'

            def __init__(self):
                super(AccessListHardware.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"egress" : ("egress", AccessListHardware.Nodes.Node.Egress), "ingress" : ("ingress", AccessListHardware.Nodes.Node.Ingress)}
                self._child_list_classes = {}

                self.node_name = YLeaf(YType.str, "node-name")

                self.egress = AccessListHardware.Nodes.Node.Egress()
                self.egress.parent = self
                self._children_name_map["egress"] = "egress"
                self._children_yang_names.add("egress")

                self.ingress = AccessListHardware.Nodes.Node.Ingress()
                self.ingress.parent = self
                self._children_name_map["ingress"] = "ingress"
                self._children_yang_names.add("ingress")
                self._segment_path = lambda: "node" + "[node-name='" + self.node_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ncs6k-acl-oper:access-list-hardware/nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(AccessListHardware.Nodes.Node, ['node_name'], name, value)


            class Egress(Entity):
                """
                Accesslist direction egress
                
                .. attribute:: ipv4
                
                	Accesslist version IPv4
                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4>`
                
                .. attribute:: ipv6
                
                	Accesslist version IPv6
                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6>`
                
                

                """

                _prefix = 'ncs6k-acl-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(AccessListHardware.Nodes.Node.Egress, self).__init__()

                    self.yang_name = "egress"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ipv4" : ("ipv4", AccessListHardware.Nodes.Node.Egress.Ipv4), "ipv6" : ("ipv6", AccessListHardware.Nodes.Node.Egress.Ipv6)}
                    self._child_list_classes = {}

                    self.ipv4 = AccessListHardware.Nodes.Node.Egress.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._children_yang_names.add("ipv4")

                    self.ipv6 = AccessListHardware.Nodes.Node.Egress.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._children_yang_names.add("ipv6")
                    self._segment_path = lambda: "egress"


                class Ipv4(Entity):
                    """
                    Accesslist version IPv4
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:   :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Egress.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "egress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"accesses" : ("accesses", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses)}
                        self._child_list_classes = {}

                        self.accesses = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._children_yang_names.add("accesses")
                        self._segment_path = lambda: "ipv4"


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of    :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"access" : ("access", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access)}

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  <key>
                            
                            	Name of the access list
                            	**type**\:  str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:   :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"implicit" : ("implicit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit), "sequence-briefs" : ("sequence_briefs", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs), "sequence-details" : ("sequence_details", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails)}
                                self._child_list_classes = {}

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.implicit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"
                                self._children_yang_names.add("implicit")

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._children_yang_names.add("sequence-briefs")

                                self.sequence_details = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"
                                self._children_yang_names.add("sequence-details")
                                self._segment_path = lambda: "access" + "[access-list-name='" + self.access_list_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of    :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"implicit-acl" : ("implicit_acl", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl)}

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:   :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:   :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"common-acl-implicit" : ("common_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit), "interface-acl-implicit" : ("interface_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit)}
                                        self._child_list_classes = {}

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"
                                        self._children_yang_names.add("common-acl-implicit")

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._children_yang_names.add("interface-acl-implicit")
                                        self._segment_path = lambda: "implicit-acl"


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "common-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "interface-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-brief" : ("sequence_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief)}

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of    :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl" : ("common_acl", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl), "interface-acl" : ("interface_acl", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-detail" : ("sequence_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail)}

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of    :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl-detail" : ("common_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail), "interface-acl-detail" : ("interface_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                class Ipv6(Entity):
                    """
                    Accesslist version IPv6
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:   :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Egress.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "egress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"accesses" : ("accesses", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses)}
                        self._child_list_classes = {}

                        self.accesses = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._children_yang_names.add("accesses")
                        self._segment_path = lambda: "ipv6"


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of    :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"access" : ("access", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access)}

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  <key>
                            
                            	Name of the access list
                            	**type**\:  str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:   :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"implicit" : ("implicit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit), "sequence-briefs" : ("sequence_briefs", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs), "sequence-details" : ("sequence_details", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails)}
                                self._child_list_classes = {}

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.implicit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"
                                self._children_yang_names.add("implicit")

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._children_yang_names.add("sequence-briefs")

                                self.sequence_details = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"
                                self._children_yang_names.add("sequence-details")
                                self._segment_path = lambda: "access" + "[access-list-name='" + self.access_list_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of    :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"implicit-acl" : ("implicit_acl", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl)}

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:   :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:   :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"common-acl-implicit" : ("common_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit), "interface-acl-implicit" : ("interface_acl_implicit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit)}
                                        self._child_list_classes = {}

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"
                                        self._children_yang_names.add("common-acl-implicit")

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._children_yang_names.add("interface-acl-implicit")
                                        self._segment_path = lambda: "implicit-acl"


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "common-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "interface-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-brief" : ("sequence_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief)}

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of    :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl" : ("common_acl", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl), "interface-acl" : ("interface_acl", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-detail" : ("sequence_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail)}

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of    :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl-detail" : ("common_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail), "interface-acl-detail" : ("interface_acl_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Egress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


            class Ingress(Entity):
                """
                Accesslist direction ingress
                
                .. attribute:: ipv4
                
                	Accesslist version IPv4
                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4>`
                
                .. attribute:: ipv6
                
                	Accesslist version IPv6
                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6>`
                
                

                """

                _prefix = 'ncs6k-acl-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(AccessListHardware.Nodes.Node.Ingress, self).__init__()

                    self.yang_name = "ingress"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ipv4" : ("ipv4", AccessListHardware.Nodes.Node.Ingress.Ipv4), "ipv6" : ("ipv6", AccessListHardware.Nodes.Node.Ingress.Ipv6)}
                    self._child_list_classes = {}

                    self.ipv4 = AccessListHardware.Nodes.Node.Ingress.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._children_yang_names.add("ipv4")

                    self.ipv6 = AccessListHardware.Nodes.Node.Ingress.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._children_yang_names.add("ipv6")
                    self._segment_path = lambda: "ingress"


                class Ipv4(Entity):
                    """
                    Accesslist version IPv4
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:   :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "ingress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"accesses" : ("accesses", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses)}
                        self._child_list_classes = {}

                        self.accesses = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._children_yang_names.add("accesses")
                        self._segment_path = lambda: "ipv4"


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of    :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"access" : ("access", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access)}

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  <key>
                            
                            	Name of the access list
                            	**type**\:  str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:   :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"implicit" : ("implicit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit), "sequence-briefs" : ("sequence_briefs", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs), "sequence-details" : ("sequence_details", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails)}
                                self._child_list_classes = {}

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.implicit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"
                                self._children_yang_names.add("implicit")

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._children_yang_names.add("sequence-briefs")

                                self.sequence_details = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"
                                self._children_yang_names.add("sequence-details")
                                self._segment_path = lambda: "access" + "[access-list-name='" + self.access_list_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of    :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"implicit-acl" : ("implicit_acl", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl)}

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:   :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:   :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"common-acl-implicit" : ("common_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit), "interface-acl-implicit" : ("interface_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit)}
                                        self._child_list_classes = {}

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"
                                        self._children_yang_names.add("common-acl-implicit")

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._children_yang_names.add("interface-acl-implicit")
                                        self._segment_path = lambda: "implicit-acl"


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "common-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "interface-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-brief" : ("sequence_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief)}

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of    :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl" : ("common_acl", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl), "interface-acl" : ("interface_acl", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-detail" : ("sequence_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail)}

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of    :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl-detail" : ("common_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail), "interface-acl-detail" : ("interface_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv4.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                class Ipv6(Entity):
                    """
                    Accesslist version IPv6
                    
                    .. attribute:: accesses
                    
                    	Table for access lists
                    	**type**\:   :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses>`
                    
                    

                    """

                    _prefix = 'ncs6k-acl-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "ingress"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"accesses" : ("accesses", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses)}
                        self._child_list_classes = {}

                        self.accesses = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                        self._children_yang_names.add("accesses")
                        self._segment_path = lambda: "ipv6"


                    class Accesses(Entity):
                        """
                        Table for access lists
                        
                        .. attribute:: access
                        
                        	List of ACLs
                        	**type**\: list of    :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access>`
                        
                        

                        """

                        _prefix = 'ncs6k-acl-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses, self).__init__()

                            self.yang_name = "accesses"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"access" : ("access", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access)}

                            self.access = YList(self)
                            self._segment_path = lambda: "accesses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses, [], name, value)


                        class Access(Entity):
                            """
                            List of ACLs
                            
                            .. attribute:: access_list_name  <key>
                            
                            	Name of the access list
                            	**type**\:  str
                            
                            .. attribute:: implicit
                            
                            	Implicit ACL information
                            	**type**\:   :py:class:`Implicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit>`
                            
                            .. attribute:: sequence_briefs
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs>`
                            
                            .. attribute:: sequence_details
                            
                            	Table of all sequence numbers per ACL
                            	**type**\:   :py:class:`SequenceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails>`
                            
                            

                            """

                            _prefix = 'ncs6k-acl-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access, self).__init__()

                                self.yang_name = "access"
                                self.yang_parent_name = "accesses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"implicit" : ("implicit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit), "sequence-briefs" : ("sequence_briefs", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs), "sequence-details" : ("sequence_details", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails)}
                                self._child_list_classes = {}

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.implicit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit()
                                self.implicit.parent = self
                                self._children_name_map["implicit"] = "implicit"
                                self._children_yang_names.add("implicit")

                                self.sequence_briefs = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs()
                                self.sequence_briefs.parent = self
                                self._children_name_map["sequence_briefs"] = "sequence-briefs"
                                self._children_yang_names.add("sequence-briefs")

                                self.sequence_details = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails()
                                self.sequence_details.parent = self
                                self._children_name_map["sequence_details"] = "sequence-details"
                                self._children_yang_names.add("sequence-details")
                                self._segment_path = lambda: "access" + "[access-list-name='" + self.access_list_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access, ['access_list_name'], name, value)


                            class Implicit(Entity):
                                """
                                Implicit ACL information
                                
                                .. attribute:: implicit_acl
                                
                                	Implicit ACL Entries across Slices
                                	**type**\: list of    :py:class:`ImplicitAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit, self).__init__()

                                    self.yang_name = "implicit"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"implicit-acl" : ("implicit_acl", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl)}

                                    self.implicit_acl = YList(self)
                                    self._segment_path = lambda: "implicit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit, [], name, value)


                                class ImplicitAcl(Entity):
                                    """
                                    Implicit ACL Entries across Slices
                                    
                                    .. attribute:: common_acl_implicit
                                    
                                    	Common ACL Implicit Entries
                                    	**type**\:   :py:class:`CommonAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit>`
                                    
                                    .. attribute:: interface_acl_implicit
                                    
                                    	Interface ACL Implicit Entries
                                    	**type**\:   :py:class:`InterfaceAclImplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl, self).__init__()

                                        self.yang_name = "implicit-acl"
                                        self.yang_parent_name = "implicit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"common-acl-implicit" : ("common_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit), "interface-acl-implicit" : ("interface_acl_implicit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit)}
                                        self._child_list_classes = {}

                                        self.common_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit()
                                        self.common_acl_implicit.parent = self
                                        self._children_name_map["common_acl_implicit"] = "common-acl-implicit"
                                        self._children_yang_names.add("common-acl-implicit")

                                        self.interface_acl_implicit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit()
                                        self.interface_acl_implicit.parent = self
                                        self._children_name_map["interface_acl_implicit"] = "interface-acl-implicit"
                                        self._children_yang_names.add("interface-acl-implicit")
                                        self._segment_path = lambda: "implicit-acl"


                                    class CommonAclImplicit(Entity):
                                        """
                                        Common ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit, self).__init__()

                                            self.yang_name = "common-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "common-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "common-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.CommonAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclImplicit(Entity):
                                        """
                                        Interface ACL Implicit Entries
                                        
                                        .. attribute:: implicit_deny
                                        
                                        	Implicit deny
                                        	**type**\:   :py:class:`ImplicitDeny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny>`
                                        
                                        .. attribute:: implicit_ndna_permit
                                        
                                        	Implicit NDNA permit
                                        	**type**\:   :py:class:`ImplicitNdnaPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit>`
                                        
                                        .. attribute:: implicit_ndns_permit
                                        
                                        	Implicit NDNS permit
                                        	**type**\:   :py:class:`ImplicitNdnsPermit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit, self).__init__()

                                            self.yang_name = "interface-acl-implicit"
                                            self.yang_parent_name = "implicit-acl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"implicit-deny" : ("implicit_deny", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny), "implicit-ndna-permit" : ("implicit_ndna_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit), "implicit-ndns-permit" : ("implicit_ndns_permit", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit)}
                                            self._child_list_classes = {}

                                            self.implicit_deny = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny()
                                            self.implicit_deny.parent = self
                                            self._children_name_map["implicit_deny"] = "implicit-deny"
                                            self._children_yang_names.add("implicit-deny")

                                            self.implicit_ndna_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit()
                                            self.implicit_ndna_permit.parent = self
                                            self._children_name_map["implicit_ndna_permit"] = "implicit-ndna-permit"
                                            self._children_yang_names.add("implicit-ndna-permit")

                                            self.implicit_ndns_permit = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit()
                                            self.implicit_ndns_permit.parent = self
                                            self._children_name_map["implicit_ndns_permit"] = "implicit-ndns-permit"
                                            self._children_yang_names.add("implicit-ndns-permit")
                                            self._segment_path = lambda: "interface-acl-implicit"


                                        class ImplicitDeny(Entity):
                                            """
                                            Implicit deny
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, self).__init__()

                                                self.yang_name = "implicit-deny"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-deny"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-deny"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitDeny.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnaPermit(Entity):
                                            """
                                            Implicit NDNA permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, self).__init__()

                                                self.yang_name = "implicit-ndna-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndna-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndna-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnaPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                        class ImplicitNdnsPermit(Entity):
                                            """
                                            Implicit NDNS permit
                                            
                                            .. attribute:: ace_brief
                                            
                                            	ACE brief information
                                            	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief>`
                                            
                                            .. attribute:: ace_detail
                                            
                                            	ACE detail information
                                            	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, self).__init__()

                                                self.yang_name = "implicit-ndns-permit"
                                                self.yang_parent_name = "interface-acl-implicit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief)}
                                                self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail)}

                                                self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief()
                                                self.ace_brief.parent = self
                                                self._children_name_map["ace_brief"] = "ace-brief"
                                                self._children_yang_names.add("ace-brief")

                                                self.ace_detail = YList(self)
                                                self._segment_path = lambda: "implicit-ndns-permit"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit, [], name, value)


                                            class AceBrief(Entity):
                                                """
                                                ACE brief information
                                                
                                                .. attribute:: default_next_hop_enabled
                                                
                                                	Default next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: grant
                                                
                                                	Either permit or deny
                                                	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                                
                                                .. attribute:: hits
                                                
                                                	Number of TCAM hits
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: logging_enabled
                                                
                                                	Logging enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress>`
                                                
                                                .. attribute:: next_hop_enabled
                                                
                                                	Next hop enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: npu_id
                                                
                                                	NPU Id
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: per_ace_icmp_enabled
                                                
                                                	Per ACE ICMP enabled/disabled
                                                	**type**\:  bool
                                                
                                                .. attribute:: total_tcam_entries
                                                
                                                	Number of TCAM entries
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, self).__init__()

                                                    self.yang_name = "ace-brief"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress)}
                                                    self._child_list_classes = {}

                                                    self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                    self.grant = YLeaf(YType.enumeration, "grant")

                                                    self.hits = YLeaf(YType.uint64, "hits")

                                                    self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                    self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                    self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                    self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                    self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                    self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress()
                                                    self.next_hop_address.parent = self
                                                    self._children_name_map["next_hop_address"] = "next-hop-address"
                                                    self._children_yang_names.add("next-hop-address")
                                                    self._segment_path = lambda: "ace-brief"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                                class NextHopAddress(Entity):
                                                    """
                                                    Next hop address
                                                    
                                                    .. attribute:: address_type
                                                    
                                                    	AddressType
                                                    	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 address type
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, self).__init__()

                                                        self.yang_name = "next-hop-address"
                                                        self.yang_parent_name = "ace-brief"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.address_type = YLeaf(YType.enumeration, "address-type")

                                                        self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                        self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                        self._segment_path = lambda: "next-hop-address"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                            class AceDetail(Entity):
                                                """
                                                ACE detail information
                                                
                                                .. attribute:: entry_id
                                                
                                                	Entry ID
                                                	**type**\:  int
                                                
                                                	**range:** \-2147483648..2147483647
                                                
                                                .. attribute:: ipv4tcam
                                                
                                                	IPv4 TCAM entries
                                                	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam>`
                                                
                                                .. attribute:: ipv6tcam
                                                
                                                	IPv6 TCAM entries
                                                	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, self).__init__()

                                                    self.yang_name = "ace-detail"
                                                    self.yang_parent_name = "implicit-ndns-permit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam)}
                                                    self._child_list_classes = {}

                                                    self.entry_id = YLeaf(YType.int32, "entry-id")

                                                    self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam()
                                                    self.ipv4tcam.parent = self
                                                    self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                    self._children_yang_names.add("ipv4tcam")

                                                    self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam()
                                                    self.ipv6tcam.parent = self
                                                    self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                    self._children_yang_names.add("ipv6tcam")
                                                    self._segment_path = lambda: "ace-detail"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail, ['entry_id'], name, value)


                                                class Ipv4Tcam(Entity):
                                                    """
                                                    IPv4 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam, self).__init__()

                                                        self.yang_name = "ipv4tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv4tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	Pfilter IPv4 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	Pfilter IPv4 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: value
                                                        
                                                        	Pfilter IPv4 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv4tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"


                                                        class Mask(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            Pfilter IPv4 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: destination_address
                                                            
                                                            	Destination address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: dscp
                                                            
                                                            	DSCP
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_address
                                                            
                                                            	Source address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flag value
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: ttl
                                                            
                                                            	TTL
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.destination_address = YLeaf(YType.str, "destination-address")

                                                                self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                                self.dscp = YLeaf(YType.uint8, "dscp")

                                                                self.fragment = YLeaf(YType.uint16, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.source_address = YLeaf(YType.str, "source-address")

                                                                self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                                self.ttl = YLeaf(YType.uint32, "ttl")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flag value
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                class Ipv6Tcam(Entity):
                                                    """
                                                    IPv6 TCAM entries
                                                    
                                                    .. attribute:: tcam_entry
                                                    
                                                    	TCAM entries
                                                    	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam, self).__init__()

                                                        self.yang_name = "ipv6tcam"
                                                        self.yang_parent_name = "ace-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry)}
                                                        self._child_list_classes = {}

                                                        self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry()
                                                        self.tcam_entry.parent = self
                                                        self._children_name_map["tcam_entry"] = "tcam-entry"
                                                        self._children_yang_names.add("tcam-entry")
                                                        self._segment_path = lambda: "ipv6tcam"


                                                    class TcamEntry(Entity):
                                                        """
                                                        TCAM entries
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_address_mask
                                                        
                                                        	Destination address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: mask
                                                        
                                                        	IPv6 TCAM mask
                                                        	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                        
                                                        .. attribute:: result
                                                        
                                                        	IPv6 TCAM result
                                                        	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_address_mask
                                                        
                                                        	Source address mask
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: value
                                                        
                                                        	IPv6 TCAM value
                                                        	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                            self.yang_name = "tcam-entry"
                                                            self.yang_parent_name = "ipv6tcam"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                            self._child_list_classes = {}

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                            self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                            self.mask.parent = self
                                                            self._children_name_map["mask"] = "mask"
                                                            self._children_yang_names.add("mask")

                                                            self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                            self.result.parent = self
                                                            self._children_name_map["result"] = "result"
                                                            self._children_yang_names.add("result")

                                                            self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                            self.value.parent = self
                                                            self._children_name_map["value"] = "value"
                                                            self._children_yang_names.add("value")
                                                            self._segment_path = lambda: "tcam-entry"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                        class Mask(Entity):
                                                            """
                                                            IPv6 TCAM mask
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                                self.yang_name = "mask"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "mask"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "mask"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Result(Entity):
                                                            """
                                                            IPv6 TCAM result
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                                self.yang_name = "result"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "result"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "result"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                        class Value(Entity):
                                                            """
                                                            IPv6 TCAM value
                                                            
                                                            .. attribute:: acl_id
                                                            
                                                            	ACL ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: authentication_header
                                                            
                                                            	Authentication header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_header
                                                            
                                                            	Destination header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: destination_range_id
                                                            
                                                            	Destination range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: fragment
                                                            
                                                            	Fragment
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: layer4_destination_port
                                                            
                                                            	Layer 4 destination port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: layer4_source_port
                                                            
                                                            	Layer 4 source port
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: packet_length_range
                                                            
                                                            	Packet length range ID
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: protocol
                                                            
                                                            	protocol flags
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: receive_transition_gap_header
                                                            
                                                            	Receive/transmit transition gap header
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: source_range_id
                                                            
                                                            	Source range
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: tcp_flags
                                                            
                                                            	TCP flags
                                                            	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                            
                                                            .. attribute:: tos
                                                            
                                                            	TOS
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                                self.yang_name = "value"
                                                                self.yang_parent_name = "tcam-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                                self._child_list_classes = {}

                                                                self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                                self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                                self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                                self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                                self.fragment = YLeaf(YType.uint8, "fragment")

                                                                self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                                self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                                self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                                self.protocol = YLeaf(YType.uint8, "protocol")

                                                                self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                                self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                                self.tos = YLeaf(YType.uint8, "tos")

                                                                self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                                self.tcp_flags.parent = self
                                                                self._children_name_map["tcp_flags"] = "tcp-flags"
                                                                self._children_yang_names.add("tcp-flags")
                                                                self._segment_path = lambda: "value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                            class TcpFlags(Entity):
                                                                """
                                                                TCP flags
                                                                
                                                                .. attribute:: acknowledge
                                                                
                                                                	TCP acknowledge flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: finish
                                                                
                                                                	TCP finish flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: push
                                                                
                                                                	TCP push flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: reset
                                                                
                                                                	TCP reset flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: synchronization
                                                                
                                                                	TCP synchronization flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: urgent
                                                                
                                                                	TCP urgent flag
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                

                                                                """

                                                                _prefix = 'ncs6k-acl-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                    self.yang_name = "tcp-flags"
                                                                    self.yang_parent_name = "value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                    self.finish = YLeaf(YType.uint8, "finish")

                                                                    self.push = YLeaf(YType.uint8, "push")

                                                                    self.reset = YLeaf(YType.uint8, "reset")

                                                                    self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                    self.urgent = YLeaf(YType.uint8, "urgent")
                                                                    self._segment_path = lambda: "tcp-flags"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.Implicit.ImplicitAcl.InterfaceAclImplicit.ImplicitNdnsPermit.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                            class SequenceBriefs(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_brief
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs, self).__init__()

                                    self.yang_name = "sequence-briefs"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-brief" : ("sequence_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief)}

                                    self.sequence_brief = YList(self)
                                    self._segment_path = lambda: "sequence-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs, [], name, value)


                                class SequenceBrief(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Brief ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl
                                    
                                    	Common ACL information across Slices
                                    	**type**\: list of    :py:class:`CommonAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl>`
                                    
                                    .. attribute:: interface_acl
                                    
                                    	Interface ACL information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAcl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, self).__init__()

                                        self.yang_name = "sequence-brief"
                                        self.yang_parent_name = "sequence-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl" : ("common_acl", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl), "interface-acl" : ("interface_acl", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl = YList(self)
                                        self.interface_acl = YList(self)
                                        self._segment_path = lambda: "sequence-brief" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief, ['sequence_number'], name, value)


                                    class CommonAcl(Entity):
                                        """
                                        Common ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, self).__init__()

                                            self.yang_name = "common-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "common-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "common-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.CommonAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                    class InterfaceAcl(Entity):
                                        """
                                        Interface ACL information across Slices
                                        
                                        .. attribute:: default_next_hop_enabled
                                        
                                        	Default next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: grant
                                        
                                        	Either permit or deny
                                        	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                        
                                        .. attribute:: hits
                                        
                                        	Number of TCAM hits
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: logging_enabled
                                        
                                        	Logging enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_address
                                        
                                        	Next hop address
                                        	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress>`
                                        
                                        .. attribute:: next_hop_enabled
                                        
                                        	Next hop enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: npu_id
                                        
                                        	NPU Id
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: per_ace_icmp_enabled
                                        
                                        	Per ACE ICMP enabled/disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: total_tcam_entries
                                        
                                        	Number of TCAM entries
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, self).__init__()

                                            self.yang_name = "interface-acl"
                                            self.yang_parent_name = "sequence-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress)}
                                            self._child_list_classes = {}

                                            self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                            self.grant = YLeaf(YType.enumeration, "grant")

                                            self.hits = YLeaf(YType.uint64, "hits")

                                            self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                            self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                            self.npu_id = YLeaf(YType.uint8, "npu-id")

                                            self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                            self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                            self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress()
                                            self.next_hop_address.parent = self
                                            self._children_name_map["next_hop_address"] = "next-hop-address"
                                            self._children_yang_names.add("next-hop-address")
                                            self._segment_path = lambda: "interface-acl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                        class NextHopAddress(Entity):
                                            """
                                            Next hop address
                                            
                                            .. attribute:: address_type
                                            
                                            	AddressType
                                            	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 address type
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, self).__init__()

                                                self.yang_name = "next-hop-address"
                                                self.yang_parent_name = "interface-acl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address_type = YLeaf(YType.enumeration, "address-type")

                                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                self._segment_path = lambda: "next-hop-address"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceBriefs.SequenceBrief.InterfaceAcl.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                            class SequenceDetails(Entity):
                                """
                                Table of all sequence numbers per ACL
                                
                                .. attribute:: sequence_detail
                                
                                	Detail ACL information
                                	**type**\: list of    :py:class:`SequenceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail>`
                                
                                

                                """

                                _prefix = 'ncs6k-acl-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails, self).__init__()

                                    self.yang_name = "sequence-details"
                                    self.yang_parent_name = "access"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sequence-detail" : ("sequence_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail)}

                                    self.sequence_detail = YList(self)
                                    self._segment_path = lambda: "sequence-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails, [], name, value)


                                class SequenceDetail(Entity):
                                    """
                                    Detail ACL information
                                    
                                    .. attribute:: sequence_number  <key>
                                    
                                    	Detail ACL information for a particular sequence
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: common_acl_detail
                                    
                                    	Common ACL detail information across Slices
                                    	**type**\: list of    :py:class:`CommonAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail>`
                                    
                                    .. attribute:: interface_acl_detail
                                    
                                    	Interface ACL detail information across Slices
                                    	**type**\: list of    :py:class:`InterfaceAclDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail>`
                                    
                                    

                                    """

                                    _prefix = 'ncs6k-acl-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, self).__init__()

                                        self.yang_name = "sequence-detail"
                                        self.yang_parent_name = "sequence-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"common-acl-detail" : ("common_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail), "interface-acl-detail" : ("interface_acl_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail)}

                                        self.sequence_number = YLeaf(YType.int32, "sequence-number")

                                        self.common_acl_detail = YList(self)
                                        self.interface_acl_detail = YList(self)
                                        self._segment_path = lambda: "sequence-detail" + "[sequence-number='" + self.sequence_number.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail, ['sequence_number'], name, value)


                                    class CommonAclDetail(Entity):
                                        """
                                        Common ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, self).__init__()

                                            self.yang_name = "common-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "common-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "common-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.CommonAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                    class InterfaceAclDetail(Entity):
                                        """
                                        Interface ACL detail information across Slices
                                        
                                        .. attribute:: ace_brief
                                        
                                        	ACE brief information
                                        	**type**\:   :py:class:`AceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief>`
                                        
                                        .. attribute:: ace_detail
                                        
                                        	ACE detail information
                                        	**type**\: list of    :py:class:`AceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail>`
                                        
                                        

                                        """

                                        _prefix = 'ncs6k-acl-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, self).__init__()

                                            self.yang_name = "interface-acl-detail"
                                            self.yang_parent_name = "sequence-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ace-brief" : ("ace_brief", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief)}
                                            self._child_list_classes = {"ace-detail" : ("ace_detail", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail)}

                                            self.ace_brief = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief()
                                            self.ace_brief.parent = self
                                            self._children_name_map["ace_brief"] = "ace-brief"
                                            self._children_yang_names.add("ace-brief")

                                            self.ace_detail = YList(self)
                                            self._segment_path = lambda: "interface-acl-detail"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail, [], name, value)


                                        class AceBrief(Entity):
                                            """
                                            ACE brief information
                                            
                                            .. attribute:: default_next_hop_enabled
                                            
                                            	Default next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: grant
                                            
                                            	Either permit or deny
                                            	**type**\:   :py:class:`SseGrant <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SseGrant>`
                                            
                                            .. attribute:: hits
                                            
                                            	Number of TCAM hits
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: logging_enabled
                                            
                                            	Logging enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\:   :py:class:`NextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress>`
                                            
                                            .. attribute:: next_hop_enabled
                                            
                                            	Next hop enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: npu_id
                                            
                                            	NPU Id
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: per_ace_icmp_enabled
                                            
                                            	Per ACE ICMP enabled/disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: total_tcam_entries
                                            
                                            	Number of TCAM entries
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, self).__init__()

                                                self.yang_name = "ace-brief"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"next-hop-address" : ("next_hop_address", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress)}
                                                self._child_list_classes = {}

                                                self.default_next_hop_enabled = YLeaf(YType.boolean, "default-next-hop-enabled")

                                                self.grant = YLeaf(YType.enumeration, "grant")

                                                self.hits = YLeaf(YType.uint64, "hits")

                                                self.logging_enabled = YLeaf(YType.boolean, "logging-enabled")

                                                self.next_hop_enabled = YLeaf(YType.boolean, "next-hop-enabled")

                                                self.npu_id = YLeaf(YType.uint8, "npu-id")

                                                self.per_ace_icmp_enabled = YLeaf(YType.boolean, "per-ace-icmp-enabled")

                                                self.total_tcam_entries = YLeaf(YType.uint32, "total-tcam-entries")

                                                self.next_hop_address = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress()
                                                self.next_hop_address.parent = self
                                                self._children_name_map["next_hop_address"] = "next-hop-address"
                                                self._children_yang_names.add("next-hop-address")
                                                self._segment_path = lambda: "ace-brief"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief, ['default_next_hop_enabled', 'grant', 'hits', 'logging_enabled', 'next_hop_enabled', 'npu_id', 'per_ace_icmp_enabled', 'total_tcam_entries'], name, value)


                                            class NextHopAddress(Entity):
                                                """
                                                Next hop address
                                                
                                                .. attribute:: address_type
                                                
                                                	AddressType
                                                	**type**\:   :py:class:`SsePfilterAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.SsePfilterAddr>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address type
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, self).__init__()

                                                    self.yang_name = "next-hop-address"
                                                    self.yang_parent_name = "ace-brief"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.address_type = YLeaf(YType.enumeration, "address-type")

                                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                                    self._segment_path = lambda: "next-hop-address"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceBrief.NextHopAddress, ['address_type', 'ipv4_address', 'ipv6_address'], name, value)


                                        class AceDetail(Entity):
                                            """
                                            ACE detail information
                                            
                                            .. attribute:: entry_id
                                            
                                            	Entry ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: ipv4tcam
                                            
                                            	IPv4 TCAM entries
                                            	**type**\:   :py:class:`Ipv4Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam>`
                                            
                                            .. attribute:: ipv6tcam
                                            
                                            	IPv6 TCAM entries
                                            	**type**\:   :py:class:`Ipv6Tcam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam>`
                                            
                                            

                                            """

                                            _prefix = 'ncs6k-acl-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, self).__init__()

                                                self.yang_name = "ace-detail"
                                                self.yang_parent_name = "interface-acl-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ipv4tcam" : ("ipv4tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam), "ipv6tcam" : ("ipv6tcam", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam)}
                                                self._child_list_classes = {}

                                                self.entry_id = YLeaf(YType.int32, "entry-id")

                                                self.ipv4tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam()
                                                self.ipv4tcam.parent = self
                                                self._children_name_map["ipv4tcam"] = "ipv4tcam"
                                                self._children_yang_names.add("ipv4tcam")

                                                self.ipv6tcam = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam()
                                                self.ipv6tcam.parent = self
                                                self._children_name_map["ipv6tcam"] = "ipv6tcam"
                                                self._children_yang_names.add("ipv6tcam")
                                                self._segment_path = lambda: "ace-detail"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail, ['entry_id'], name, value)


                                            class Ipv4Tcam(Entity):
                                                """
                                                IPv4 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam, self).__init__()

                                                    self.yang_name = "ipv4tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv4tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	Pfilter IPv4 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	Pfilter IPv4 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: value
                                                    
                                                    	Pfilter IPv4 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv4tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"


                                                    class Mask(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        Pfilter IPv4 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: destination_address
                                                        
                                                        	Destination address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: dscp
                                                        
                                                        	DSCP
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_address
                                                        
                                                        	Source address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flag value
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: ttl
                                                        
                                                        	TTL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.destination_address = YLeaf(YType.str, "destination-address")

                                                            self.destination_range_id = YLeaf(YType.uint16, "destination-range-id")

                                                            self.dscp = YLeaf(YType.uint8, "dscp")

                                                            self.fragment = YLeaf(YType.uint16, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint16, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint8, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.source_address = YLeaf(YType.str, "source-address")

                                                            self.source_range_id = YLeaf(YType.uint16, "source-range-id")

                                                            self.ttl = YLeaf(YType.uint32, "ttl")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value, ['acl_id', 'destination_address', 'destination_range_id', 'dscp', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'source_address', 'source_range_id', 'ttl'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flag value
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv4Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                            class Ipv6Tcam(Entity):
                                                """
                                                IPv6 TCAM entries
                                                
                                                .. attribute:: tcam_entry
                                                
                                                	TCAM entries
                                                	**type**\:   :py:class:`TcamEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry>`
                                                
                                                

                                                """

                                                _prefix = 'ncs6k-acl-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam, self).__init__()

                                                    self.yang_name = "ipv6tcam"
                                                    self.yang_parent_name = "ace-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"tcam-entry" : ("tcam_entry", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry)}
                                                    self._child_list_classes = {}

                                                    self.tcam_entry = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry()
                                                    self.tcam_entry.parent = self
                                                    self._children_name_map["tcam_entry"] = "tcam-entry"
                                                    self._children_yang_names.add("tcam-entry")
                                                    self._segment_path = lambda: "ipv6tcam"


                                                class TcamEntry(Entity):
                                                    """
                                                    TCAM entries
                                                    
                                                    .. attribute:: destination_address
                                                    
                                                    	Destination address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: destination_address_mask
                                                    
                                                    	Destination address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mask
                                                    
                                                    	IPv6 TCAM mask
                                                    	**type**\:   :py:class:`Mask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask>`
                                                    
                                                    .. attribute:: result
                                                    
                                                    	IPv6 TCAM result
                                                    	**type**\:   :py:class:`Result <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result>`
                                                    
                                                    .. attribute:: source_address
                                                    
                                                    	Source address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: source_address_mask
                                                    
                                                    	Source address mask
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: value
                                                    
                                                    	IPv6 TCAM value
                                                    	**type**\:   :py:class:`Value <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ncs6k-acl-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, self).__init__()

                                                        self.yang_name = "tcam-entry"
                                                        self.yang_parent_name = "ipv6tcam"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"mask" : ("mask", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask), "result" : ("result", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result), "value" : ("value", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value)}
                                                        self._child_list_classes = {}

                                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                                        self.destination_address_mask = YLeaf(YType.str, "destination-address-mask")

                                                        self.source_address = YLeaf(YType.str, "source-address")

                                                        self.source_address_mask = YLeaf(YType.str, "source-address-mask")

                                                        self.mask = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask()
                                                        self.mask.parent = self
                                                        self._children_name_map["mask"] = "mask"
                                                        self._children_yang_names.add("mask")

                                                        self.result = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result()
                                                        self.result.parent = self
                                                        self._children_name_map["result"] = "result"
                                                        self._children_yang_names.add("result")

                                                        self.value = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value()
                                                        self.value.parent = self
                                                        self._children_name_map["value"] = "value"
                                                        self._children_yang_names.add("value")
                                                        self._segment_path = lambda: "tcam-entry"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry, ['destination_address', 'destination_address_mask', 'source_address', 'source_address_mask'], name, value)


                                                    class Mask(Entity):
                                                        """
                                                        IPv6 TCAM mask
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, self).__init__()

                                                            self.yang_name = "mask"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "mask"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "mask"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Mask.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Result(Entity):
                                                        """
                                                        IPv6 TCAM result
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, self).__init__()

                                                            self.yang_name = "result"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "result"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "result"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Result.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)


                                                    class Value(Entity):
                                                        """
                                                        IPv6 TCAM value
                                                        
                                                        .. attribute:: acl_id
                                                        
                                                        	ACL ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: authentication_header
                                                        
                                                        	Authentication header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_header
                                                        
                                                        	Destination header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: destination_range_id
                                                        
                                                        	Destination range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: fragment
                                                        
                                                        	Fragment
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: layer4_destination_port
                                                        
                                                        	Layer 4 destination port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: layer4_source_port
                                                        
                                                        	Layer 4 source port
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: packet_length_range
                                                        
                                                        	Packet length range ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol
                                                        
                                                        	protocol flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: receive_transition_gap_header
                                                        
                                                        	Receive/transmit transition gap header
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_range_id
                                                        
                                                        	Source range
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tcp_flags
                                                        
                                                        	TCP flags
                                                        	**type**\:   :py:class:`TcpFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs6k_acl_oper.AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags>`
                                                        
                                                        .. attribute:: tos
                                                        
                                                        	TOS
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ncs6k-acl-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, self).__init__()

                                                            self.yang_name = "value"
                                                            self.yang_parent_name = "tcam-entry"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"tcp-flags" : ("tcp_flags", AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags)}
                                                            self._child_list_classes = {}

                                                            self.acl_id = YLeaf(YType.uint16, "acl-id")

                                                            self.authentication_header = YLeaf(YType.uint8, "authentication-header")

                                                            self.destination_header = YLeaf(YType.uint8, "destination-header")

                                                            self.destination_range_id = YLeaf(YType.uint32, "destination-range-id")

                                                            self.fragment = YLeaf(YType.uint8, "fragment")

                                                            self.layer4_destination_port = YLeaf(YType.uint16, "layer4-destination-port")

                                                            self.layer4_source_port = YLeaf(YType.uint32, "layer4-source-port")

                                                            self.packet_length_range = YLeaf(YType.uint32, "packet-length-range")

                                                            self.protocol = YLeaf(YType.uint8, "protocol")

                                                            self.receive_transition_gap_header = YLeaf(YType.uint8, "receive-transition-gap-header")

                                                            self.source_range_id = YLeaf(YType.uint32, "source-range-id")

                                                            self.tos = YLeaf(YType.uint8, "tos")

                                                            self.tcp_flags = AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags()
                                                            self.tcp_flags.parent = self
                                                            self._children_name_map["tcp_flags"] = "tcp-flags"
                                                            self._children_yang_names.add("tcp-flags")
                                                            self._segment_path = lambda: "value"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value, ['acl_id', 'authentication_header', 'destination_header', 'destination_range_id', 'fragment', 'layer4_destination_port', 'layer4_source_port', 'packet_length_range', 'protocol', 'receive_transition_gap_header', 'source_range_id', 'tos'], name, value)


                                                        class TcpFlags(Entity):
                                                            """
                                                            TCP flags
                                                            
                                                            .. attribute:: acknowledge
                                                            
                                                            	TCP acknowledge flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: finish
                                                            
                                                            	TCP finish flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: push
                                                            
                                                            	TCP push flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: reset
                                                            
                                                            	TCP reset flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: synchronization
                                                            
                                                            	TCP synchronization flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: urgent
                                                            
                                                            	TCP urgent flag
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ncs6k-acl-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, self).__init__()

                                                                self.yang_name = "tcp-flags"
                                                                self.yang_parent_name = "value"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.acknowledge = YLeaf(YType.uint8, "acknowledge")

                                                                self.finish = YLeaf(YType.uint8, "finish")

                                                                self.push = YLeaf(YType.uint8, "push")

                                                                self.reset = YLeaf(YType.uint8, "reset")

                                                                self.synchronization = YLeaf(YType.uint8, "synchronization")

                                                                self.urgent = YLeaf(YType.uint8, "urgent")
                                                                self._segment_path = lambda: "tcp-flags"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(AccessListHardware.Nodes.Node.Ingress.Ipv6.Accesses.Access.SequenceDetails.SequenceDetail.InterfaceAclDetail.AceDetail.Ipv6Tcam.TcamEntry.Value.TcpFlags, ['acknowledge', 'finish', 'push', 'reset', 'synchronization', 'urgent'], name, value)

    def clone_ptr(self):
        self._top_entity = AccessListHardware()
        return self._top_entity

